# -*- coding: utf-8 -*-
#
# Copyright (C) 2011-2015 Red Hat, Inc.
#
# Authors:
# Than Ngo <than@redhat.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os
import gettext
import gi

gi.require_version('Gtk', '3.0')
from gi.repository import Gtk

DOMAIN = "system-config-kdump"

#
# I18N
#
gettext.textdomain(DOMAIN)
_ = gettext.gettext

if os.access("dialog_call_error.glade", os.F_OK):
    gladefile = "dialog_call_error.glade"
else:
    gladefile = "/usr/share/system-config-kdump/dialog_call_error.glade"

builder = Gtk.Builder()
builder.set_translation_domain(DOMAIN)
builder.add_from_file(gladefile)

def on_button1_clicked(button):
    builder.get_object("dialog_call_error").hide()

def show_call_error_message(text, title, cmd, stdout, stderr, parent = None):
    """
    Show up gtk window with error message indicating which command failed.
    text is message text - some talk about the whole problem
    title is window title
    cmd is command which failed
    stdout is standard output from the command
    stderr is standard error from the command
    parrent is parent window
    """
    if cmd == "" and stdout == "" and stderr == "":
        return show_error_message(text, title, parent)
    handlers = { "on_button1_clicked" : on_button1_clicked }
    builder.connect_signals(handlers)
    dlg = builder.get_object("dialog_call_error")
    dlg.set_transient_for(parent)
    dlg.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
    dlg.set_modal(True)
    dlg.set_title(title)
    builder.get_object("label_message").set_text(text)
    builder.get_object("tv_command").get_buffer().set_text(cmd)
    builder.get_object("tv_stdout").get_buffer().set_text(stdout)
    builder.get_object("tv_stderr").get_buffer().set_text(stderr)
    dlg.run()
    dlg.hide()    
    return False

def show_error_message(text, title, parent = None):
    """
    Show up gtk window with error message.
    Text is message text.
    Title is window title.
    """
    dlg = Gtk.MessageDialog(None, 0, Gtk.MessageType.ERROR,
                            Gtk.ButtonsType.OK, text)
    dlg.set_transient_for(parent)
    dlg.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
    dlg.set_modal(True)
    dlg.set_title(title)
    dlg.run()
    dlg.destroy()
    return False

def show_message(text, title, msgtype=None, parent = None):
    """
    Show up gtk information message.
    Text is message text.
    Title is window title.
    With msgtype you can override type of gtk MessageDialog
    """
    if msgtype is None:
        msgtype = Gtk.MessageType.INFO

    dlg = Gtk.MessageDialog(None, 0, msgtype, Gtk.ButtonsType.OK, text)
    dlg.set_transient_for(parent)
    dlg.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
    dlg.set_modal(True)
    dlg.set_title(title)
    dlg.run()
    dlg.destroy()

def yes_no_dialog(text, title, parent = None):
    """
    Show up gtk message with yes and no buttons.
    Text is message text.
    Title is window title.
    Returns True for Yes clicked, False for No.
    """
    dlg = Gtk.MessageDialog(None, 0, Gtk.MessageType.QUESTION,
                            Gtk.ButtonsType.YES_NO, text)
    dlg.set_transient_for(parent)
    dlg.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
    dlg.set_modal(True)
    dlg.set_title(title)
    ret = dlg.run()
    dlg.destroy()
    if ret == Gtk.ResponseType.YES:
        retc = True
    else:
        retc = False

    return retc

if __name__ == "__main__":
    yes_no_dialog("Yes no dialog test\n"*10, "TEST")
    show_message("Show message test\n"*10, "TEST")
    show_error_message("Show error message test\n"*10, "TEST")
    show_call_error_message("Show call error message test\n"*10,
        "TEST",
        "command test\n"*5,
        "stdout test\n"*5,
        "stderr test\n"*5)
    show_call_error_message("Show call error message test2\n"*10,
        "TEST", "", "", "")
    show_call_error_message("Show call error message test3\n"*10,
        "TEST", "", "a", "")
