import gi

gi.require_version('Gtk', '3.0')
from gi.repository import Gtk, GObject, GLib

class ProgressWindow(Gtk.Window):
    def __init__(self, title, label):
        Gtk.Window.__init__(self, Gtk.WindowType.TOPLEVEL)
        self.set_deletable(False)
        self.set_resizable(False)
        self.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
        self.set_modal(True)
        self.set_title(title)
        self.progress = Gtk.ProgressBar()
        self.progress.show()

        self.label = Gtk.Label(label)
        self.label.show()

        vbox = Gtk.VBox()
        vbox.set_spacing(10)
        vbox.set_border_width(10)
        vbox.show()

        vbox.pack_start(self.label, True, False, 4)
        vbox.pack_start(self.progress, True, False, 4)

        self.add(vbox)

        self.timer = None

    def set_label(self, label):
        self.label.set_text(label)

    def start(self):
        self.deiconify()
        self.timer = GObject.timeout_add(500, self.update_cb)

    def update_cb(self):
        self.progress.pulse()
        return True

    def stop(self):
        if self.timer:
            GObject.source_remove(self.timer)
            self.timer = None

    def show(self):
        self.start()
        Gtk.Window.show(self)

    def hide(self):
        self.stop()
        Gtk.Window.hide(self)

if __name__ == "__main__":
    win = ProgressWindow("system-config-kdump", "")
    win.connect("delete-event", Gtk.main_quit)
    win.show_all()
    Gtk.main()
